Index: trunk/psLib/src/image/psImageExtraction.h
===================================================================
--- trunk/psLib/src/image/psImageExtraction.h	(revision 1920)
+++ trunk/psLib/src/image/psImageExtraction.h	(revision 1924)
@@ -10,6 +10,6 @@
 *  @author Robert DeSonia, MHPCC
 *
-*  @version $Revision: 1.15 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2004-09-28 23:26:48 $
+*  @version $Revision: 1.16 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2004-09-29 01:10:27 $
 *
 *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -114,12 +114,22 @@
 /** Extract pixels from rectlinear region to a vector (array of floats).
  *
  *  The output vector contains either nx or ny elements, based on the value of 
  *  the direction: e.g., if direction is PS_CUT_X_POS, there are nx elements.
  *  The input region is collapsed in the perpendicular direction, and each 
  *  element of the output vectors is derived from the statistics of the pixels
  *  at that direction coordinate. The statistic used to derive the output 
  *  vector value is specified by stats. Only one of the statistics choices may 
  *  be specified, otherwise the function must return an error. This function 
  *  must be defined for the following types: psS8, psU16, psF32, psF64.
  *
  * @return psVector    the resulting vector
@@ -134,8 +144,8 @@
     const psImage* restrict mask,      ///< the mask for the input image.
     unsigned int maskVal,              ///< the mask value to apply to the mask
-    unsigned int col,                  ///< the leftmost column of the slice region
-    unsigned int row,                  ///< the bottommost row of the slice region
-    unsigned int numCols,              ///< the number of columns in the slice region
-    unsigned int numRows,              ///< the number of rows in the slice region
+    int col0,                          ///< the leftmost column of the slice region
+    int row0,                          ///< the bottommost row of the slice region
+    int col1,                          ///< exclusive end column of the slice region
+    int row1,                           ///< exclusive end row of the slice region
     psImageCutDirection direction,     ///< the slice dimension and direction
     const psStats* stats               ///< the statistic to perform in slice operation
@@ -114,12 +114,22 @@
 /** Extract pixels from rectlinear region to a vector (array of floats).
  *
- *  The output vector contains either nx or ny elements, based on the value of 
- *  the direction: e.g., if direction is PS_CUT_X_POS, there are nx elements.
- *  The input region is collapsed in the perpendicular direction, and each 
- *  element of the output vectors is derived from the statistics of the pixels
- *  at that direction coordinate. The statistic used to derive the output 
- *  vector value is specified by stats. Only one of the statistics choices may 
- *  be specified, otherwise the function must return an error. This function 
- *  must be defined for the following types: psS8, psU16, psF32, psF64.
+ *  The output vector contains either col1-col0 or row1-row0 elements, based 
+ *  on the value of the direction: e.g., if direction is PS_CUT_X_POS, there 
+ *  are col1-col0 elements. The region to be  sliced  is defined by the 
+ *  lower-left corner, (col0,row0), and the upper-right corner, (col1,row1). 
+ *  Note that the row and column of the  upper right-hand corner  are NOT 
+ *  included in the region. In the event that col1 or row1 are negative, they
+ *  shall be interpreted as being relative to the size of the parent image in 
+ *  that dimension. The input region is collapsed in the direction perpendicular 
+ *  to that specified by direction, and each element of the output vectors is 
+ *  derived from the statistics of the pixels at that direction coordinate. The
+ *  statistic used to derive the output vector value is specified by stats. 
+ *  If mask is non-NULL, pixels for which the corresponding mask pixel 
+ *  matches maskVal are excluded from operations. If coords is not NULL, the 
+ *  calculated coordinates along the slice are returned in this vector. Only 
+ *  one of the statistics choices may be specified, otherwise the function 
+ *  must return an error.
+ *
+ *  This function is defined for the following types: psS8, psU16, psF32, psF64.
  *
  * @return psVector    the resulting vector
